@@ -10,7 +10,6 @@ import wcwidth
 import urllib3
 from uuid import getnode as get_mac
 import sys
-
 from pathlib import Path
 
 downloads_path = str(Path.home() / "Downloads")
@@ -71,8 +70,18 @@ def clear():
         json.dump({}, file)
 
 
+def create_file_if_not_exists():
+    cache_file = Path(FILE_PATH)
+    cache_file.touch(exist_ok=True)
+    file = open(FILE_PATH, "w+")
+    data = file.read()
+    if not data:
+        file.write("{}")
+
+
 @app.command(name="list")
 def list(search: str = typer.Argument("")):
+    create_file_if_not_exists()
     start_time = current_milli_time()
     os.system('source ~/.bash_profile')
     # 这里暂存到临时文件中，避免控制台输出
@@ -105,7 +114,8 @@ def list(search: str = typer.Argument("")):
         for cache_idx, cache in enumerate(get(task['key']), 2):
             cache_item = [cache_idx, ','.join(cache['method']['params'])]
             cache_list.append(cache_item)
-        typer.secho(tabulate(cache_list, headers=["ID", "Parameters"], tablefmt='pretty'), fg=typer.colors.BLUE, bold=True)
+        typer.secho(tabulate(cache_list, headers=["ID", "Parameters"], tablefmt='pretty'), fg=typer.colors.BLUE,
+                    bold=True)
         typer.secho("\n")
 
         cache_id = typer.prompt("选择缓存项")
